#
# spec file for package plexus-compiler
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-compiler
Version:        2.14.2
Release:        1.2
Summary:        Compiler call initiators for Plexus
License:        Apache-2.0 AND MIT
Group:          Development/Libraries/Java
URL:            https://github.com/codehaus-plexus/plexus-compiler
Source0:        https://github.com/codehaus-plexus/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        LICENSE.MIT
Source100:      %{name}-build.tar.xz
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  ecj
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  plexus-utils
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildArch:      noarch

%description
Plexus Compiler adds support for using various compilers from a
unified api. Support for javac is available in main package. For
additional compilers see %{name}-extras package.

%package extras
Summary:        Extra compiler support for %{name}
License:        Apache-2.0
Group:          Development/Libraries/Java

%description extras
Additional support for csharp, eclipse and jikes compilers

%package javadoc
Summary:        Javadoc for %{name}
License:        Apache-1.1 AND Apache-2.0 AND MIT
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version} -a100

cp %{SOURCE1} LICENSE
cp %{SOURCE2} LICENSE.MIT

%pom_disable_module plexus-compiler-aspectj plexus-compilers
# missing com.google.errorprone:error_prone_core
%pom_disable_module plexus-compiler-javac-errorprone plexus-compilers

# don't build/install compiler-test module, it needs maven2 test harness
%pom_disable_module plexus-compiler-test

# don't generate requires on test dependency (see #1007498)
%pom_xpath_remove "pom:dependency[pom:artifactId[text()='plexus-compiler-test']]" plexus-compilers

%pom_change_dep org.codehaus.plexus:plexus-testing :::test plexus-compilers/plexus-compiler-eclipse

%pom_remove_dep -r :plexus-xml

%pom_remove_plugin :maven-site-plugin

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  ecj \
  org.eclipse.sisu.inject \
  org.eclipse.sisu.plexus \
  plexus/utils \
  slf4j/api

# Tests are skipped because of unavailable plexus-compiler-test artifact
%{ant} \
  -Dtest.skip=true \
  package javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}/%{name}
for i in plexus-compiler-api plexus-compiler-manager \
    plexus-compilers/plexus-compiler-csharp \
    plexus-compilers/plexus-compiler-eclipse \
    plexus-compilers/plexus-compiler-javac; do
  install -pm 0644 ${i}/target/$(basename ${i})-%{version}.jar %{buildroot}%{_javadir}/%{name}/$(basename ${i}).jar
done

# poms
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
# These ones belong to the *-extras package
for i in plexus-compilers/plexus-compiler-csharp \
    plexus-compilers/plexus-compiler-eclipse; do
  bsnm=$(basename ${i})
  %{mvn_install_pom} ${i}/pom.xml  %{buildroot}%{_mavenpomdir}/%{name}/$bsnm.pom
  %add_maven_depmap %{name}/$bsnm.pom %{name}/$bsnm.jar -f extras
done
# These ones end-up in the main package
for i in plexus-compiler-api plexus-compiler-manager \
    plexus-compilers/plexus-compiler-javac; do
  bsnm=$(basename ${i})
  %{mvn_install_pom} ${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/$bsnm.pom
  %add_maven_depmap %{name}/$bsnm.pom %{name}/$bsnm.jar
done

# javadoc
for i in plexus-compiler-api plexus-compiler-manager \
    plexus-compilers/plexus-compiler-javac \
    plexus-compilers/plexus-compiler-csharp \
    plexus-compilers/plexus-compiler-eclipse; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}/${i}
  cp -pr ${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/${i}/
done
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%dir %{_javadir}/%{name}
%license LICENSE LICENSE.MIT

%files extras -f .mfiles-extras

%files javadoc
%license LICENSE LICENSE.MIT
%{_javadocdir}/%{name}

%changelog
* Wed Jan 31 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 2.14.2
  * Removed
    + Drop J2ObjC compiler
  * New features and improvements
    + Update AspectJ Compiler to 1.9.21 to support Java 21
    + Require JDK 17 for build
    + Improve locking on JavacCompiler
    + Include 'parameter' and 'preview' describe log
    + Switch to SISU annotations and plugin, fixes #217
    + Support jdk 21
    + Require Maven 3.5.4+
    + Require Java 11 for plexus-compiler-eclipse an
    javac-errorprone and aspectj compilers
    + Add support to run its with Java 20
  * Bug Fixes
    + Fix javac memory leak
    + Validate zip file names before extracting (Zip Slip)
    + Restore AbstractCompiler#getLogger() method
    + Return empty list for not existing source root location
    + Improve javac error output parsing - Fix #336
* Wed Sep 20 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 2.13.0
  * New features and improvements
    + fully ignore any possible jdk bug
    + MCOMPILER-402: Add implicitOption to CompilerConfiguration
    + Add a custom compile argument
    replaceProcessorPathWithProcessorModulePath to force the
    plugin replace processorPath with processormodulepath
    + describe compiler configuration on run
    + simplify "Compiling" info message: display relative path
  * Bug Fixes
    + Respect CompilerConfiguration.sourceFiles in
    EclipseJavaCompiler
    + Avoid NPE in AspectJCompilerTest on AspectJ 1.9.8+
  * Dependency updates
    + Bump maven-surefire-plugin from 3.0.0-M5 to 3.0.0-M6
    + Bump error_prone_core from 2.11.0 to 2.13.1
    + Bump github/codeql-action from 1 to 2
    + Bump ecj from 3.28.0 to 3.29.0
    + Bump release-drafter/release-drafter from 5.18.1 to 5.19.0
    + Bump ecj from 3.29.0 to 3.30.0
    + Bump maven-invoker-plugin from 3.2.2 to 3.3.0
    + Bump maven-enforcer-plugin from 3.0.0 to 3.1.0
    + Bump error_prone_core from 2.13.1 to 2.14.0
    + Bump maven-surefire-plugin from 3.0.0-M6 to 3.0.0-M7
    + Bump ecj from 3.31.0 to 3.32.0
    + Bump junit-bom from 5.9.0 to 5.9.1
    + Bump ecj from 3.30.0 to 3.31.0
    + Bump groovy from 3.0.12 to 3.0.13
    + Bump groovy-json from 3.0.12 to 3.0.13
    + Bump groovy-xml from 3.0.12 to 3.0.13
    + Bump animal-sniffer-maven-plugin from 1.21 to 1.22
    + Bump error_prone_core from 2.14.0 to 2.15.0
    + Bump junit-bom from 5.8.2 to 5.9.0
    + Bump groovy-xml from 3.0.11 to 3.0.12
    + Bump groovy-json from 3.0.11 to 3.0.12
    + Bump groovy from 3.0.11 to 3.0.12
  * Maintenance
    + Require Maven 3.2.5
    + add it for issue #183 but using javac compiler, use properties
    for versions in its
    + cleanup deprecated unused code
  * Build
    + use shared release drafter
* Sat May 21 2022 Fridrich Strba <fstrba@suse.com>
- Plexus testing is a dependency with scope test
* Sat Mar 12 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 2.11.1
  * Removed:
    + remove jikes compiler
  * New features and improvements
    + add paremeter to configure javac feature --enable-preview
    + add workaround to jdk bug JDK-8210649
    + make java 11 as project base but keep javac release 8, we
    will be able to upgrade ecj and errorprone
    + Bump plexus-components from 6.5 to 6.6 and upgrade to junit5
    + javac dump debug file should not be written in classes
    directory as it will be included in jar. change directory and
    make name configurable
    + add adopt-openj9 build
    + Fix AspectJ basics
    + fix methods of lint and warning
    + Add new showLint compiler configuration
    + add jdk distribution to the matrix
    + Added primitive support for --processor-module-path
    + Issue #111 - Refactor and add unit tests for support for
    multiple --add-exports custom compiler arguments
    + Add Maven Compiler Plugin compiler it tests
    + Close StandardJavaFileManager
    + Use latest ecj from official Eclipse release
  * Bug fixes:
    + [eclipse-compiler] Resort sources to have module-info.java
    first
    + Issue #106: Retain error messages from annotation processors
    + Issue #147: Support module-path for ECJ
    + Issue #166: Fix maven dependencies
    + eclipse compiler: set generated source dir even if no
    annotation processor is configured
    + CSharp compiler: fix role
    + Eclipse compiler: close the StandardJavaFileManager
    + Use plexus annotations rather than doclet to fix javadoc with
    java11
    + fix Java15 build
    + Update Error prone 2.4
    + Rename method, now that EA of JDK 16 is available
    + Eclipse Compiler Support release specifier instead of
    source/target
    + Issue #73: Use configured file encoding for JSR-199 Eclipse
    compiler
  * Dependency updates
    + Bump ecj from 3.24.0 to 3.28.0
    + Bump error_prone_core from 2.10.0 to 2.11.0
    + Bump release-drafter/release-drafter from 5.18.0 to 5.18.1
    + Bump plexus-components from 6.5 to 6.6 and upgrade to junit5
    + Bump release-drafter/release-drafter from 5.17.6 to 5.18.0
    + Bump animal-sniffer-maven-plugin from 1.20 to 1.21
    + Bump assertj-core from 3.21.0 to 3.22.0
    + Bump release-drafter/release-drafter from 5.15.0 to 5.17.6
    + Bump plexus-component-annotations from 2.1.0 to 2.1.1
    + Bump junit-jupiter-api from 5.8.1 to 5.8.2
    + Issue #166: Fix maven dependencies
    + Bump error_prone_core from 2.9.0 to 2.10.0
    + Bump error_prone_core from 2.8.1 to 2.9.0
    + Bump maven-enforcer-plugin from 3.0.0-M3 to 3.0.0
    + Bump actions/cache from 2.1.5 to 2.1.6
    + Bump error_prone_core from 2.6.0 to 2.8.1
    + Bump actions/cache from v2.1.4 to v2.1.5
    + Bump release-drafter/release-drafter from v5.13.0 to v5.15.0
    + Bump actions/cache from v2.1.3 to v2.1.4
    + Bump animal-sniffer-maven-plugin from 1.19 to 1.20
    + Bump maven-invoker-plugin from 3.2.1 to 3.2.2
    + Bump junit from 4.13.1 to 4.13.2
    + Bump release-drafter/release-drafter from v5.12.1 to v5.13.0
    + Bump ecj from 3.23.0 to 3.24.0
    + Bump actions/cache from v2.1.2 to v2.1.3
    + Bump release-drafter/release-drafter from v5.11.0 to v5.12.1
    + Bump junit from 4.13 to 4.13.1
    + Bump maven-artifact from 2.0 to 2.2.1
    + Bump maven-settings from 2.0 to 2.2.1
    + Bump actions/cache from v2.1.1 to v2.1.2
    + Bump ecj from 3.22.0 to 3.23.0
    + Bump plexus-component-annotations from 1.7.1 to 2.1.0
    + Bump actions/cache from v2.1.0 to v2.1.1
    + Bump plexus-components from 6.1 to 6.3
    + Bump junit from 4.12 to 4.13
    + Bump animal-sniffer-maven-plugin from 1.16 to 1.19
    + Bump aspectj.version from 1.9.2 to 1.9.6
    + Bump actions/cache from v1 to v2.1.0
  * needed by the latest maven-compiler-plugin
- Rewrite the plexus metadata generation in the ant build files
  * it is now possible to give it an ad-hoc classpath to look for
    dependencies
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Do not distribute the parent poms, since they only bring in more
  dependencies
* Mon Mar 11 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of plexus-compiler 2.8.2
- Generate and customize ant build files
